@@ -1,18 +1,18 @@
-/* $Id: daemonize.h,v 1.6 2008/01/29 13:04:46 nanard Exp $ */
+/* $Id: daemonize.h,v 1.8 2012/09/27 16:00:44 nanard Exp $ */
 /* MiniUPnP project
  * http://miniupnp.free.fr/ or http://miniupnp.tuxfamily.org/
- * (c) 2006 Thomas Bernard 
+ * (c) 2006 Thomas Bernard
  * This software is subject to the conditions detailed
  * in the LICENCE file provided within the distribution */
 
-#ifndef __DAEMONIZE_H__
-#define __DAEMONIZE_H__
+#ifndef DAEMONIZE_H_INCLUDED
+#define DAEMONIZE_H_INCLUDED
 
 #include "config.h"
 
 #ifndef USE_DAEMON
 /* daemonize()
- * "fork" to background, detach from terminal, etc... 
+ * "fork" to background, detach from terminal, etc...
  * returns: pid of the daemon, exits upon failure */
 int
 daemonize(void);
