@@ -1,4 +1,4 @@
-/* $Id: ifacewatch.c,v 1.19 2018/02/23 13:01:23 nanard Exp $ */
+/* $Id: ifacewatch.c,v 1.20 2018/04/22 19:39:34 nanard Exp $ */
 /* MiniUPnP project
  * (c) 2011-2018 Thomas Bernard
  * website : http://miniupnp.free.fr/ or https://miniupnp.tuxfamily.org/
@@ -99,6 +99,9 @@ ProcessInterfaceWatch(int s, int s_ssdp, int s_ssdp6)
 	struct rtattr *rta;
 	int ifa_len;
 
+#ifndef ENABLE_IPV6
+	(void)s_ssdp6;
+#endif
 	iov.iov_base = buffer;
 	iov.iov_len = sizeof(buffer);
 
@@ -206,6 +209,9 @@ ProcessInterfaceWatch(int s, int s_ssdp, int s_ssdp6)
 	int family = AF_UNSPEC;
 	int prefixlen = 0;
 
+#ifndef ENABLE_IPV6
+	(void)s_ssdp6;
+#endif
 	address[0] = '\0';
 	ifname[0] = '\0';
 
