@@ -1,4 +1,4 @@
-/* $Id: minissdpd.c,v 1.55 2018/02/03 22:17:32 nanard Exp $ */
+/* $Id: minissdpd.c,v 1.56 2019/02/10 13:44:48 nanard Exp $ */
 /* vim: tabstop=4 shiftwidth=4 noexpandtab
  * MiniUPnP project
  * (c) 2007-2018 Thomas Bernard
@@ -318,6 +318,7 @@ updateDevice(const struct header * headers, time_t t)
 				if(!tmp)	/* allocation error */
 				{
 					syslog(LOG_ERR, "updateDevice() : memory allocation error");
+					*pp = p->next;	/* remove "p" from the list */
 					free(p);
 					return 0;
 				}
@@ -747,7 +748,7 @@ ParseSSDPPacket(int s, const char * p, ssize_t n,
 			}
 		}
 		linestart = lineend;
-		while((*linestart == '\n' || *linestart == '\r') && linestart < p + n)
+		while((linestart < p + n) && (*linestart == '\n' || *linestart == '\r'))
 			linestart++;
 	}
 #if 0
